mock_supabase_http_client library
Support for doing something awesome.
More dartdocs go here.
Classes
- MockSupabaseHttpClient
- A mock HTTP client for testing Supabase applications that simulates a Supabase API requests and responses by storing data in memory.
Enums
- RequestType
- Represents the different types of HTTP requests that can be made to the Supabase API